@@ -425,7 +425,7 @@ int ExtAppRegistry::configVhostOwnPhp(HttpVHost *pVHost)
         }
 
         iAutoStart = ConfigCtx::getCurConfigCtx()->
-                                getLongValue(pNode, "autoStart", 0, 3, 0);
+                                getLongValue(pNode, "autoStart", 0, 2, 1);
     
         pPath = pNode->getChildValue("path");
         
@@ -502,7 +502,6 @@ int ExtAppRegistry::configVhostOwnPhp(HttpVHost *pVHost)
             config.setStartByServer(iAutoStart);
             config.setPhpHandler(1);
             config.config(pNode);
-            config.setRunOnStartUp(0);//For Vhost inherit app not to auto start
             config.setUGid(pVHost->getUid(), pVHost->getGid());
         }
     }
@@ -559,6 +558,7 @@ ExtWorker *ExtAppRegistry::configExtApp(const XmlNode *pNode, const HttpVHost *p
     const char *pUri;
     char buf[MAX_PATH_LEN];
     int iAutoStart = 0;
+    int iRunOnStartup = 0;
     const char *pPath = NULL;
     ExtWorker *pWorker = NULL;
     ExtWorkerConfig *pConfig = NULL;
@@ -601,7 +601,6 @@ ExtWorker *ExtAppRegistry::configExtApp(const XmlNode *pNode, const HttpVHost *p
         pName = appNameVh;
     }
     ConfigCtx currentCtx(pName);
-
     
     iType -= HandlerType::HT_CGI;
     
@@ -661,7 +660,7 @@ ExtWorker *ExtAppRegistry::configExtApp(const XmlNode *pNode, const HttpVHost *p
             iAutoStart = 1;
         else
             iAutoStart = ConfigCtx::getCurConfigCtx()->getLongValue(pNode, "autoStart",
-                         0, 3, 0);
+                         0, 2, 1);
 
         if (iAutoStart && strlen(pUri) > 6 && strncasecmp(pUri, "uds://", 6) == 0)
         {
@@ -770,13 +769,11 @@ ExtWorker *ExtAppRegistry::configExtApp(const XmlNode *pNode, const HttpVHost *p
         LocalWorkerConfig &config = pApp->getConfig();
         config.setAppPath(pPath);
         config.setStartByServer(iAutoStart);
-        int detached = (iAutoStart == 3);
-        config.setDetached(detached);
         config.setPhpHandler(iType == EA_LSAPI);
         config.config(pNode);
         config.configExtAppUserGroup(pNode, iType, achName);
         
-        if (detached)
+        if (config.isDetached())
         {
             if (!pVHost)
             {
