@@ -35,13 +35,14 @@ HttpServerConfig::HttpServerConfig()
     , m_iMaxDynRespHeaderLen(DEFAULT_DYN_RESP_HEADER_LEN)
     , m_iMaxKeepAliveRequests(100)
     , m_iSmartKeepAlive(0)
-    , m_iUseSendfile(0)
     , m_iAutoLoadHtaccess(0)
+    , m_iUseSendfile(0)
     , m_iFollowSymLink(1)
     , m_iGzipCompress(0)
     , m_iDynGzipCompress(0)
     , m_iCompressLevel(4)
     , m_iBrCompress(0)
+    , m_iEnableLve(0)
     , m_iMaxFcgiInstances(2000)
     , m_iMaxTempFileSize(10240)
     , m_iConnTimeout(300)
@@ -51,6 +52,7 @@ HttpServerConfig::HttpServerConfig()
     , m_iScriptForbiddenBits(000)   //S_IWOTH | S_IWGRP )
     , m_iDirForbiddenBits(000)   //S_IWOTH | S_IWGRP )
     , m_iRestartTimeout(300)
+    , m_nCpuAffinity(0)
     , m_iDnsLookup(1)
     , m_iUseProxyHeader(0)
     , m_iEnableH2c(0)
