@@ -23,7 +23,10 @@ enum LS_OFFLOAD_STATE
     LS_OFFLOAD_NOT_INUSE,
     LS_OFFLOAD_ENQUEUE,
     LS_OFFLOAD_PROCESSING,
-    LS_OFFLOAD_DONE,
+    LS_OFFLOAD_IN_FINISH_QUEUE,
+    LS_OFFLOAD_FINISH_CB,
+    LS_OFFLOAD_FINISH_CB_DONE,
+    LS_OFFLOAD_FINISH_CB_BYPASS,
     LS_OFFLOAD_BYPASS,
     LS_OFFLOAD_ENQUEUE_FAIL
 };
