@@ -96,6 +96,7 @@ HioHandler *H2Connection::get()
         delete pConn;
         return NULL;
     }
+    lshpack_enc_use_hist(&pConn->m_hpack_enc, 1);
     lshpack_dec_init(&pConn->m_hpack_dec);
     return pConn;
 }
@@ -1000,8 +1001,8 @@ int H2Connection::decodeData(const unsigned char *pSrc,
     int total_cookie_size = 0;
     char *out = buf;
     char *out_end = buf + sizeof(buf);
-    uint16_t name_len = 0 ;
-    uint16_t val_len = 0;
+    unsigned name_len = 0 ;
+    unsigned val_len = 0;
     int regular_header = 0;
     uint32_t  hpack_idx;
 
@@ -1565,7 +1566,7 @@ int H2Connection::encodeHeaders(HttpRespHeaders *pRespHeaders,
 
     char *p = (char *)HttpStatusCode::getInstance().getCodeString(
                   pRespHeaders->getHttpCode()) + 1;
-    pCur = lshpack_enc_encode(&m_hpack_enc, pCur, pBufEnd, ":status", 7, p, 3, 0);
+    pCur = lshpack_enc_encode2(&m_hpack_enc, pCur, pBufEnd, ":status", 7, p, 3, 0);
 
     pRespHeaders->dropConnectionHeaders();
 
@@ -1607,7 +1608,7 @@ int H2Connection::encodeHeaders(HttpRespHeaders *pRespHeaders,
                 str.append((char *)pIov->iov_base, pIov->iov_len);
                 str.append("\r\n", 2);
             }
-            pCur = lshpack_enc_encode(&m_hpack_enc, pCur, pBufEnd, key, keyLen,
+            pCur = lshpack_enc_encode2(&m_hpack_enc, pCur, pBufEnd, key, keyLen,
                                      (char *)pIov->iov_base, pIov->iov_len, 0);
         }
     }
@@ -1673,13 +1674,13 @@ int H2Connection::sendPushPromise(uint32_t streamId, uint32_t promise_streamId,
     uint32_t sid = htonl(promise_streamId);
     memcpy(pCur, &sid, 4);
     pCur += 4;
-    pCur = lshpack_enc_encode(&m_hpack_enc, pCur, pBufEnd, ":method", 7,
+    pCur = lshpack_enc_encode2(&m_hpack_enc, pCur, pBufEnd, ":method", 7,
                                     "GET", 3, 0);
-    pCur = lshpack_enc_encode(&m_hpack_enc, pCur, pBufEnd, ":path",   5,
+    pCur = lshpack_enc_encode2(&m_hpack_enc, pCur, pBufEnd, ":path",   5,
                                     pUrl->ptr, pUrl->len, 0);
-    pCur = lshpack_enc_encode(&m_hpack_enc, pCur, pBufEnd, ":authority", 10,
+    pCur = lshpack_enc_encode2(&m_hpack_enc, pCur, pBufEnd, ":authority", 10,
                                     pHost->ptr, pHost->len, 0);
-    pCur = lshpack_enc_encode(&m_hpack_enc, pCur, pBufEnd, ":scheme", 7,
+    pCur = lshpack_enc_encode2(&m_hpack_enc, pCur, pBufEnd, ":scheme", 7,
                                     "https", 5, 0);
     
 //     if (etag)
@@ -1692,7 +1693,7 @@ int H2Connection::sendPushPromise(uint32_t streamId, uint32_t promise_streamId,
     {
         while(headers->key.ptr)
         {
-            pCur = lshpack_enc_encode(&m_hpack_enc, pCur, pBufEnd,
+            pCur = lshpack_enc_encode2(&m_hpack_enc, pCur, pBufEnd,
                                      headers->key.ptr,
                                      headers->key.len,
                                      headers->val.ptr,
@@ -1756,8 +1757,13 @@ int H2Connection::pushPromise(uint32_t streamId, ls_str_t* pUrl,
     int ret = sendPushPromise(streamId, pushStreamId, pUrl, pHost, 
                               headers);
     if (ret == 0)
+    {
         if (createPushStream(pushStreamId, pUrl, pHost, headers) == NULL)
+        {
+            (void) sendRstFrame(pushStreamId, H2_ERROR_INTERNAL_ERROR);
             ret = -1;
+        }
+    }
     return ret;
 }
 
